Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(187)

Unified Diff: dart/runtime/lib/isolate_patch.dart

Issue 11615023: Version 0.2.9.7 (Closed) Base URL: http://dart.googlecode.com/svn/trunk/
Patch Set: Created 8 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | dart/sdk/lib/_internal/compiler/implementation/compiler.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dart/runtime/lib/isolate_patch.dart
===================================================================
--- dart/runtime/lib/isolate_patch.dart (revision 16250)
+++ dart/runtime/lib/isolate_patch.dart (working copy)
@@ -128,27 +128,27 @@
patch spawnUri(String uri) native "isolate_spawnUri";
patch class Timer {
- /* patch */ factory Timer(int milliseconds, void callback(Timer timer)) {
+ /* patch */ factory Timer(int milliSeconds, void callback(Timer timer)) {
if (_TimerFactory._factory == null) {
throw new UnsupportedError("Timer interface not supported.");
}
- return _TimerFactory._factory(milliseconds, callback, false);
+ return _TimerFactory._factory(milliSeconds, callback, false);
}
/**
* Creates a new repeating timer. The [callback] is invoked every
* [milliseconds] millisecond until cancelled.
*/
- /* patch */ factory Timer.repeating(int milliseconds,
+ /* patch */ factory Timer.repeating(int milliSeconds,
void callback(Timer timer)) {
if (_TimerFactory._factory == null) {
throw new UnsupportedError("Timer interface not supported.");
}
- return _TimerFactory._factory(milliseconds, callback, true);
+ return _TimerFactory._factory(milliSeconds, callback, true);
}
}
-typedef Timer _TimerFactoryClosure(int milliseconds,
+typedef Timer _TimerFactoryClosure(int milliSeconds,
void callback(Timer timer),
bool repeating);
« no previous file with comments | « no previous file | dart/sdk/lib/_internal/compiler/implementation/compiler.dart » ('j') | no next file with comments »
@@ -128,27 +128,27 @@
/**
* Creates a new repeating timer. The [callback] is invoked every
- * [milliseconds] millisecond until cancelled.
+ * [milliSeconds] millisecond until cancelled.
*/

Powered by Google App Engine
This is Rietveld 408576698